// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

mod font;
pub use self::font::Font;

mod font_map;
pub use self::font_map::FontMap;

pub mod functions;

#[doc(hidden)]
pub mod traits {
    pub use super::font::PangoCairoFontExt;
    pub use super::font_map::PangoCairoFontMapExt;
}
